<?php
/**
 * 短信平台API接口类
 */

class smsapi {
	public $userid;
	public $statuscode;
	private $productid, $sms_key, $smsapi_url;

	/**
	 *
	 * 初始化接口类
	 * @param int $userid 用户id
	 * @param int $productid 产品id
	 * @param string $sms_key 密钥
	 */
	public function __construct($userid = '', $productid = '', $sms_key = '') {
		$this->smsapi_url = 'http://www.lx198.com/sdk/';
		$this->userid = $userid;
		$this->productid = $productid;
		$this->sms_key = $sms_key;
	}

	/**
	 *
	 * 获取短信产品列表信息
	 */
	public function get_price() {
		$this->param = array('op'=>'sms_get_productlist');
		$res = $this->pc_file_get_contents();

		return !empty($res) ? json_decode($res, 1) : array();
	}

	/**
	 *
	 * 获取短信产品购买地址
	 */
	public function get_buyurl($productid = 0) {
		return 'http://sms.phpip.com/index.php?m=sms_service&c=center&a=buy&sms_pid='.$this->productid.'&productid='.$productid;
	}
	public function show_qf_url() {
		return $this->smsapi_url.'op=sms_qf_url&sms_uid='.$this->userid.'&sms_pid='.$this->productid.'&sms_key='.$this->sms_key;
	}
	/**
	 * 获取短信剩余条数和限制短信发送ip
	 */
	public function get_smsinfo() {
		$this->param = array('op'=>'sms_get_info');
		$res = $this->pc_file_get_contents();
		return !empty($res) ? json_decode($res, 1) : array();
	}

	/**
	 * 获取充值记录
	 */
	public function get_buyhistory() {
		$this->param = array('op'=>'sms_get_paylist');
		$res = $this->pc_file_get_contents();
		return !empty($res) ? json_decode($res, 1) : array();
	}

	/**
	 * 获取消费记录
	 * @param int $page 页码
	 */
	public function get_payhistory($page=1) {
		$this->param = array('op'=>'sms_get_report','page'=>$page);
		$res = $this->pc_file_get_contents();
		return !empty($res) ? json_decode($res, 1) : array();
	}

	/**
	 * 获取短信api帮助
	 */
	public function get_sms_help() {
		$this->param = array('op'=>'sms_help','page'=>$page);
		$res = $this->pc_file_get_contents();
		return !empty($res) ? json_decode($res, 1) : array();
	}

	/**
	 *
	 * 批量发送短信
	 * @param array $mobile 手机号码
	 * @param string $content 短信内容
	 * @param datetime $send_time 发送时间
	 * @param string $charset 短信字符类型 gbk / utf-8
	 * @param string $id_code 唯一值 、可用于验证码
	 */
	public function send_sms($mobile='', $content='', $send_time='', $charset='gbk',$id_code = '',$tplid = '',$return_code = 0) {
		//短信发送状态
		$status = $this->_sms_status();
		if(is_array($mobile)){
			$mobile = implode(",", $mobile);
		}
		$content = safe_replace($content);
		if(strtolower($charset)=='utf-8') {
			$send_content = iconv('utf-8','gbk',$content);//官网IS GBK
		}else{
			$send_content = $content;
		}
		$send_time = strtotime($send_time);

		$data = array(
						'accName'  => $this->userid,
						'accPwd'   => strtoupper(md5($this->sms_key)),
						'content'  => urlencode('您的验证码是：'.$send_content.'。请不要把验证码泄露给其他人。【动力思维】'),
						'aimcodes' => $mobile,
						'dataType' => 'json',
					);
		$post = '';
		foreach($data as $k=>$v) {
			$post .= $k.'='.$v.'&';
		}

		$smsapi_senturl = $this->smsapi_url . 'send';
        $return = $this->Post($post, $smsapi_senturl);
        $return = json_decode($return, true);
		//$arr = explode('#',$return);
		//$this->statuscode = $arr[0];

		//增加到本地数据库
		$sms_report_db = pc_base::load_model('sms_report_model');
		$send_userid = param::get_cookie('_userid') ? intval(param::get_cookie('_userid')) : 0;
		$ip = ip();
		$new_content = $content;

		if ($return['replyCode']==1) {
        	$sms_report_db->insert(array('mobile'=>$mobile,'posttime'=>SYS_TIME,'id_code'=>$id_code,'send_userid'=>$send_userid,'status'=>$this->statuscode,'msg'=>$new_content,'return_id'=>$return,'ip'=>$ip));
		} else {
         	$sms_report_db->insert(array('mobile'=>$mobile,'posttime'=>SYS_TIME,'send_userid'=>$send_userid,'status'=>'-2','msg'=>$new_content,'ip'=>$ip));
		}

		//end
		if($return_code) {
			return $arr[0];
		} else {
			return isset($status[$arr[0]]) ? $status[$arr[0]] : $arr[0];
		}
	}

	/**
	 *
	 * 获取远程内容
	 * @param $timeout 超时时间
	 */
	public function pc_file_get_contents($timeout=30) {

		$this->setting = array(
							'sms_uid'=>$this->userid,
							'sms_pid'=>$this->productid,
							'sms_passwd'=>$this->sms_key,
							);

		$this->param = array_merge($this->param, $this->setting);

		$url = $this->smsapi_url.http_build_query($this->param);
		$stream = stream_context_create(array('http' => array('timeout' => $timeout)));
		return @file_get_contents($url, 0, $stream);
	}

	/**
	 *  post数据
	 *  @param string $url		post的url
	 *  @return string			返回字符串
	 */

	private function Post($curlPost,$url){
			$curl = curl_init();
			curl_setopt($curl, CURLOPT_URL, $url);
			curl_setopt($curl, CURLOPT_HEADER, false);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_NOBODY, true);
			curl_setopt($curl, CURLOPT_POST, true);
			curl_setopt($curl, CURLOPT_POSTFIELDS, $curlPost);
			$return_str = curl_exec($curl);
			curl_close($curl);
			return $return_str;
	}

	/**
	 *  将 xml数据转换为数组格式。
	 *  @return string			返回字符串
	 */
	private function xml_to_array($xml){
		$reg = "/<(\w+)[^>]*>([\\x00-\\xFF]*)<\\/\\1>/";
		if(preg_match_all($reg, $xml, $matches)){
			$count = count($matches[0]);
			for($i = 0; $i < $count; $i++){
			$subxml= $matches[2][$i];
			$key = $matches[1][$i];
				if(preg_match( $reg, $subxml )){
					$arr[$key] = $this->xml_to_array( $subxml );
				}else{
					$arr[$key] = $subxml;
				}
			}
		}
		return $arr;
	}

	/**
	 *
	 * 接口短信状态
	 */
	private function _sms_status() {
		pc_base::load_app_func('global','sms');
		return sms_status(0,1);
	}

}
?>